@@ -7,7 +7,7 @@ Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
+published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -25,189 +25,190 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // Name: KStats
 // Desc: constructor
 //------------------------------------------------------------------------------
-KStats::KStats() : error_flag_(false) {
+KStats::KStats()
+{
 }
 
 //------------------------------------------------------------------------------
 // Name: ~KStats
 // Desc: destructor
 //------------------------------------------------------------------------------
-KStats::~KStats() {
+KStats::~KStats()
+{
 }
 
 //------------------------------------------------------------------------------
 // Name: clearAll
 // Desc: empties the data set
 //------------------------------------------------------------------------------
-void KStats::clearAll() {
-	data_.clear();
+void KStats::clearAll()
+{
+    data_.clear();
 }
 
 //------------------------------------------------------------------------------
 // Name: enterData
 // Desc: adds an item to the data set
 //------------------------------------------------------------------------------
-void KStats::enterData(const KNumber &data) {
-	data_.push_back(data);
+void KStats::enterData(const KNumber &data)
+{
+    data_.push_back(data);
 }
 
 //------------------------------------------------------------------------------
 // Name: clearLast
 // Desc: removes the last item from the data set
 //------------------------------------------------------------------------------
-void KStats::clearLast() {
-
-	if(!data_.isEmpty()) {
-		data_.pop_back();
-	}
+void KStats::clearLast()
+{
+    if (!data_.isEmpty()) {
+        data_.pop_back();
+    }
 }
 
 //------------------------------------------------------------------------------
 // Name: sum
 // Desc: calculates the SUM of all values in the data set
 //------------------------------------------------------------------------------
-KNumber KStats::sum() const {
+KNumber KStats::sum() const
+{
+    KNumber result = KNumber::Zero;
+    for (const KNumber &x : qAsConst(data_)) {
+        result += x;
+    }
 
-	KNumber result = KNumber::Zero;
-	
-	Q_FOREACH(const KNumber &x, data_) {
-		result += x;
-	}
-
-	return result;
+    return result;
 }
 
 //------------------------------------------------------------------------------
 // Name: median
 // Desc: calculates the MEDIAN of all values in the data set
 //------------------------------------------------------------------------------
-KNumber KStats::median() {
+KNumber KStats::median()
+{
+    KNumber result = KNumber::Zero;
+    size_t index;
 
-	KNumber result = KNumber::Zero;
-	size_t index;
+    unsigned int bound = count();
 
-	unsigned int bound = count();
+    if (bound == 0) {
+        error_flag_ = true;
+        return KNumber::Zero;
+    }
 
-	if (bound == 0) {
-		error_flag_ = true;
-		return KNumber::Zero;
-	}
+    if (bound == 1)
+        return data_.at(0);
 
-	if (bound == 1)
-		return data_.at(0);
+    // need to copy data_-list, because sorting afterwards
+    QVector<KNumber> tmp_data(data_);
+    std::sort(tmp_data.begin(), tmp_data.end());
 
-	// need to copy data_-list, because sorting afterwards
-	QVector<KNumber> tmp_data(data_);
-	std::sort(tmp_data.begin(), tmp_data.end());
+    if (bound & 1) { // odd
+        index = (bound - 1) / 2 + 1;
+        result = tmp_data.at(index - 1);
+    } else { // even
+        index = bound / 2;
+        result = ((tmp_data.at(index - 1)) + (tmp_data.at(index))) / KNumber(2);
+    }
 
-	if (bound & 1) {    // odd
-		index = (bound - 1) / 2 + 1;
-		result =  tmp_data.at(index - 1);
-	} else { // even
-		index = bound / 2;
-		result = ((tmp_data.at(index - 1)) + (tmp_data.at(index))) / KNumber(2);
-	}
-
-	return result;
+    return result;
 }
 
 //------------------------------------------------------------------------------
 // Name: std_kernel
 // Desc: calculates the STD Kernel of all values in the data set
 //------------------------------------------------------------------------------
-KNumber KStats::std_kernel() {
-	KNumber result           = KNumber::Zero;
-	const KNumber mean_value = mean();
+KNumber KStats::std_kernel()
+{
+    KNumber result = KNumber::Zero;
+    const KNumber mean_value = mean();
 
-	if(mean_value.type() != KNumber::TYPE_ERROR) {
-		Q_FOREACH(const KNumber &x, data_) {
-			result += (x - mean_value) * (x - mean_value);
-		}
-	}
+    if (mean_value.type() != KNumber::TYPE_ERROR) {
+        for (const KNumber &x : qAsConst(data_)) {
+            result += (x - mean_value) * (x - mean_value);
+        }
+    }
 
-	return result;
+    return result;
 }
 
 //------------------------------------------------------------------------------
 // Name: sum_of_squares
 // Desc: calculates the SUM of all values in the data set (each squared)
 //------------------------------------------------------------------------------
-KNumber KStats::sum_of_squares() const {
+KNumber KStats::sum_of_squares() const
+{
+    KNumber result = KNumber::Zero;
 
-	KNumber result = KNumber::Zero;
+    for (const KNumber &x : qAsConst(data_)) {
+        result += (x * x);
+    }
 
-	Q_FOREACH(const KNumber &x, data_) {
-		result += (x * x);
-	}
-
-	return result;
+    return result;
 }
 
 //------------------------------------------------------------------------------
 // Name: mean
 // Desc: calculates the MEAN of all values in the data set
 //------------------------------------------------------------------------------
-KNumber KStats::mean() {
+KNumber KStats::mean()
+{
+    if (data_.isEmpty()) {
+        error_flag_ = true;
+        return KNumber::Zero;
+    }
 
-	if (data_.isEmpty()) {
-		error_flag_ = true;
-		return KNumber::Zero;
-	}
-
-	return (sum() / KNumber(count()));
+    return (sum() / KNumber(count()));
 }
 
 //------------------------------------------------------------------------------
 // Name: std
 // Desc: calculates the STANDARD DEVIATION of all values in the data set
 //------------------------------------------------------------------------------
-KNumber KStats::std() {
+KNumber KStats::std()
+{
+    if (data_.isEmpty()) {
+        error_flag_ = true;
+        return KNumber::Zero;
+    }
 
-	if (data_.isEmpty()) {
-		error_flag_ = true;
-		return KNumber::Zero;
-	}
-
-	return (std_kernel() / KNumber(count())).sqrt();
+    return (std_kernel() / KNumber(count())).sqrt();
 }
 
 //------------------------------------------------------------------------------
 // Name: sample_std
 // Desc: calculates the SAMPLE STANDARD DEVIATION of all values in the data set
 //------------------------------------------------------------------------------
-KNumber KStats::sample_std() {
+KNumber KStats::sample_std()
+{
+    KNumber result = KNumber::Zero;
 
-	KNumber result = KNumber::Zero;
+    if (count() < 2) {
+        error_flag_ = true;
+        return KNumber::Zero;
+    }
 
-	if (count() < 2) {
-		error_flag_ = true;
-		return KNumber::Zero;
-	}
+    result = (std_kernel() / KNumber(count() - 1)).sqrt();
 
-	result = (std_kernel() / KNumber(count() - 1)).sqrt();
-
-	return result;
+    return result;
 }
 
 //------------------------------------------------------------------------------
 // Name: count
 // Desc: returns the amount of values in the data set
 //------------------------------------------------------------------------------
-int KStats::count() const {
-
-	return data_.size();
+int KStats::count() const
+{
+    return data_.size();
 }
 
 //------------------------------------------------------------------------------
 // Name: error
 // Desc: returns the error state AND clears it
 //------------------------------------------------------------------------------
-bool KStats::error() {
-
-	bool value = error_flag_;
-	error_flag_ = false;
-	return value;
+bool KStats::error()
+{
+    bool value = error_flag_;
+    error_flag_ = false;
+    return value;
 }
-
-
-
